==> zither-1.1.18.tar.gz: zither_prj/sitar/print_conf.c <==



#include<stdio.h>
#include<netinet/in.h>
#include<string.h>
#include<stdlib.h>
#include<pthread.h>

#include"sitar.h"
#include<almemsys/almemsys.h>

extern global_data_t gd;
extern struct scan_buf sb;



/* ----------- PRINT CONF ------------- */
int print_conf(void)
{
   fprintf(stdout,"-- SITAR CLIENT Configration setup list --\n");
   fprintf(stdout,"-- *Config File                           = %s\n", gd.fi.conf_path);
   fprintf(stdout,"-- *BAT Filename  (command list tmp file) = %s\n", gd.fi.bat_filename);
   fprintf(stdout,"-- *BAT2 Filename (monitor list tmp file) = %s\n", gd.fi.bat2_filename);
   fprintf(stdout,"-- *CRON Filename (cron file)             = %s\n", gd.fi.cronfile_filename);
   fprintf(stdout,"-- *CRON List Filename (cron list file)   = %s\n", gd.fi.cronlist_filename);
   fprintf(stdout,"-- MID dump filename   (MID list file)    = %s\n", gd.fi.midump_filename);
   fprintf(stdout,"-- SOCK_IPADDR    (server ip1)            = %s\n",gd.ip.ip_addr);
   fprintf(stdout,"-- SOCK2_IPADDR   (server ip2)            = %s\n",gd.ip.ip2_addr);
   fprintf(stdout,"-- SOCK_PORT      (server port1)          = %d\n",gd.ip.port);
   fprintf(stdout,"-- SOCK2_PORT     (server port2)          = %d\n",gd.ip.port2);
   fprintf(stdout,"-- LIFE_ONOFF     (life on off)           = %d\n",gd.ld.onoff);
   fprintf(stdout,"-- LIFE_INT       (life interval sec)     = %d\n",gd.bf.life_int);
   fprintf(stdout,"-- LIFE_LOS       (life loss time sec)    = %d\n",gd.bf.life_los);
   fprintf(stdout,"-- C_NAME         (client name)           = %s\n",gd.bf.c_name);
   fprintf(stdout,"-- C_INFO         (client info)           = %s\n",gd.bf.c_info);
   fprintf(stdout,"-- MAIL_CC        (mail cc:)              = %s\n",gd.smtp.ch_MailCc);
   fprintf(stdout,"-- BAT_INT        (No used)               = %d\n", gd.bf.bat_int);
   fprintf(stdout,"-- BAT2_INT       (monitor interval)      = %d\n", gd.bf.bat2_int);
   fprintf(stdout,"-- COMMAND_PATH   (command path)          = %s\n", gd.fi.command_path);
   fprintf(stdout,"-- CRON_PATH      (cron path)             = %s\n", gd.fi.cron_path);
   fprintf(stdout,"-- UPDATE_COM     (update command)        = %s\n", gd.fi.update_com);
   fprintf(stdout,"-- THREAD_MAX     (thread count max)      = %d\n", gd.td.tcount);
   fprintf(stdout,"-- TBUF_MAX       (thread buff count max) = %d\n", gd.td.tbufmax);
   fprintf(stdout,"-- CRON_ONOFF     (enable cron mode 1)    = %d\n", gd.cron_onoff);
   fprintf(stdout,"Version %s\n", CL_VAR);

return 0;
}

==> zither-1.1.21.tar.gz: zither_prj/sitar/print_conf.c <==



#include<stdio.h>
#include<netinet/in.h>
#include<string.h>
#include<stdlib.h>
#include<pthread.h>

#include"sitar.h"
#include<almemsys/almemsys.h>

extern global_data_t gd;
extern struct scan_buf sb;



/* ----------- PRINT CONF ------------- */
int print_conf(void)
{
   fprintf(stdout,"-- SITAR CLIENT Configration setup list --\n");
   fprintf(stdout,"-- *Config File                           = %s\n", gd.fi.conf_path);
   fprintf(stdout,"-- *BAT Filename  (command list tmp file) = %s\n", gd.fi.bat_filename);
   fprintf(stdout,"-- *BAT2 Filename (monitor list tmp file) = %s\n", gd.fi.bat2_filename);
   fprintf(stdout,"-- *CRON Filename (cron file)             = %s\n", gd.fi.cronfile_filename);
   fprintf(stdout,"-- *CRON List Filename (cron list file)   = %s\n", gd.fi.cronlist_filename);
   fprintf(stdout,"-- MID dump filename   (MID list file)    = %s\n", gd.fi.midump_filename);
   fprintf(stdout,"-- SOCK_IPADDR    (server ip1)            = %s\n",gd.ip.ip_addr);
   fprintf(stdout,"-- SOCK2_IPADDR   (server ip2)            = %s\n",gd.ip.ip2_addr);
   fprintf(stdout,"-- SOCK_PORT      (server port1)          = %d\n",gd.ip.port);
   fprintf(stdout,"-- SOCK2_PORT     (server port2)          = %d\n",gd.ip.port2);
   fprintf(stdout,"-- LIFE_ONOFF     (life on off)           = %d\n",gd.ld.onoff);
   fprintf(stdout,"-- LIFE_INT       (life interval sec)     = %d\n",gd.bf.life_int);
   fprintf(stdout,"-- LIFE_LOS       (life loss time sec)    = %d\n",gd.bf.life_los);
   fprintf(stdout,"-- C_NAME         (client name)           = %s\n",gd.bf.c_name);
   fprintf(stdout,"-- C_INFO         (client info)           = %s\n",gd.bf.c_info);
   fprintf(stdout,"-- MAIL_CC        (mail cc:)              = %s\n",gd.smtp.ch_MailCc);
   fprintf(stdout,"-- BAT_INT        (No used)               = %d\n", gd.bf.bat_int);
   fprintf(stdout,"-- BAT2_INT       (monitor interval)      = %d\n", gd.bf.bat2_int);
   fprintf(stdout,"-- COMMAND_PATH   (command path)          = %s\n", gd.fi.command_path);
   fprintf(stdout,"-- CRON_PATH      (cron path)             = %s\n", gd.fi.cron_path);
   fprintf(stdout,"-- UPDATE_COM     (update command)        = %s\n", gd.fi.update_com);
   fprintf(stdout,"-- THREAD_MAX     (in thread count)       = %d\n", gd.td.tcount);
   fprintf(stdout,"-- TBUF_MAX       (thread buff count max) = %d\n", gd.td.tbufmax);
   fprintf(stdout,"-- DNS_IP         (resolv dns ip addrses) = %s\n", gd.di.dns_name);
   fprintf(stdout,"-- MID_MAX        (MID count max)         = %d\n", gd.td.midcount);
   fprintf(stdout,"-- THREAD_LEN     (thread max count)      = %d\n", gd.td.thread_max);
   fprintf(stdout,"-- MID_INT        (MID write interval)    = %d\n", gd.td.midint);
   fprintf(stdout,"-- CRON_ONOFF     (enable cron mode 1)    = %d\n", gd.cron_onoff);
   fprintf(stdout,"Version %s\n", CL_VAR);

char * mid_max ="MID_MAX";
char * thread_len="THREAD_LEN";
char * mid_int="MID_INT";


return 0;
}
